Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: generated/googleapis/lib/adexperiencereport/v1.dart

Issue 3003493002: Api-Roll 53: 2017-08-21 (Closed)
Patch Set: Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « generated/googleapis/lib/adexchangebuyer/v1_4.dart ('k') | generated/googleapis/lib/analytics/v3.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: generated/googleapis/lib/adexperiencereport/v1.dart
diff --git a/generated/googleapis/lib/adexperiencereport/v1.dart b/generated/googleapis/lib/adexperiencereport/v1.dart
index e3a07037b16546c0dbe58b8764196830da743e21..692c9d88d3da40503781a784ffd135b62cf5d791 100644
--- a/generated/googleapis/lib/adexperiencereport/v1.dart
+++ b/generated/googleapis/lib/adexperiencereport/v1.dart
@@ -40,14 +40,18 @@ class SitesResourceApi {
_requester = client;
/**
- * Gets a summary of the ads rating of a site.
+ * Gets a summary of the ad experience rating of a site.
*
* Request parameters:
*
- * [name] - The required site name. It should be a site property registered in
- * Search
- * Console. The server will return an error of BAD_REQUEST if this field is
- * not filled in.
+ * [name] - The required site name. It should be the site property whose ad
+ * experiences
+ * may have been reviewed, and it should be URL-encoded. For example,
+ * sites/https%3A%2F%2Fwww.google.com. The server will return an error of
+ * BAD_REQUEST if this field is not filled in. Note that if the site property
+ * is not yet verified in Search Console, the reportUrl field returned by the
+ * API will lead to the verification page, prompting the user to go through
+ * that process before they can gain access to the Ad Experience Report.
* Value must have pattern "^sites/[^/]+$".
*
* Completes with a [SiteSummaryResponse].
@@ -129,25 +133,25 @@ class ViolatingSitesResourceApi {
-/** Summary of the ads rating of a site for a specific platform. */
+/** Summary of the ad experience rating of a site for a specific platform. */
class PlatformSummary {
/**
* The status of the site reviewed for the Better Ads Standards.
* Possible string values are:
* - "UNKNOWN" : Not reviewed.
* - "PASSING" : Passing.
- * - "WARNING" : Warning.
* - "FAILING" : Failing.
*/
- core.String betterAdsStatus;
+ core.String abusiveStatus;
/**
- * The status of the site reviewed for egregious ads.
+ * The status of the site reviewed for the Better Ads Standards.
* Possible string values are:
* - "UNKNOWN" : Not reviewed.
* - "PASSING" : Passing.
+ * - "WARNING" : Warning.
* - "FAILING" : Failing.
*/
- core.String egregiousStatus;
+ core.String betterAdsStatus;
/** The date on which ad filtering begins. */
core.String enforcementTime;
/**
@@ -172,12 +176,12 @@ class PlatformSummary {
PlatformSummary();
PlatformSummary.fromJson(core.Map _json) {
+ if (_json.containsKey("abusiveStatus")) {
+ abusiveStatus = _json["abusiveStatus"];
+ }
if (_json.containsKey("betterAdsStatus")) {
betterAdsStatus = _json["betterAdsStatus"];
}
- if (_json.containsKey("egregiousStatus")) {
- egregiousStatus = _json["egregiousStatus"];
- }
if (_json.containsKey("enforcementTime")) {
enforcementTime = _json["enforcementTime"];
}
@@ -200,12 +204,12 @@ class PlatformSummary {
core.Map<core.String, core.Object> toJson() {
final core.Map<core.String, core.Object> _json = new core.Map<core.String, core.Object>();
+ if (abusiveStatus != null) {
+ _json["abusiveStatus"] = abusiveStatus;
+ }
if (betterAdsStatus != null) {
_json["betterAdsStatus"] = betterAdsStatus;
}
- if (egregiousStatus != null) {
- _json["egregiousStatus"] = egregiousStatus;
- }
if (enforcementTime != null) {
_json["enforcementTime"] = enforcementTime;
}
@@ -129,25 +133,25 @@ class ViolatingSitesResourceApi {
class PlatformSummary {
/**
- * The status of the site reviewed for the Better Ads Standards.
+ * The status of the site reviewed for abusive ads.
* Possible string values are:
* - "UNKNOWN" : Not reviewed.
« no previous file with comments | « generated/googleapis/lib/adexchangebuyer/v1_4.dart ('k') | generated/googleapis/lib/analytics/v3.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698